==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/page/UserMessageHandler.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef UserMessageHandler_h
#define UserMessageHandler_h

#if ENABLE(USER_MESSAGE_HANDLERS)

#include "FrameDestructionObserver.h"
#include "UserMessageHandlerDescriptor.h"
#include <bindings/ScriptValue.h>

namespace WebCore {

class UserMessageHandler : public RefCounted<UserMessageHandler>, public FrameDestructionObserver {
public:
    static PassRef<UserMessageHandler> create(Frame& frame, UserMessageHandlerDescriptor& descriptor)
    {
        return adoptRef(*new UserMessageHandler(frame, descriptor));
    }
    virtual ~UserMessageHandler();

    void postMessage(PassRefPtr<SerializedScriptValue>);

    const AtomicString& name();
    DOMWrapperWorld& world();

private:
    UserMessageHandler(Frame&, UserMessageHandlerDescriptor&);
    
    Ref<UserMessageHandlerDescriptor> m_descriptor;
};

} // namespace WebCore

#endif // ENABLE(USER_MESSAGE_HANDLERS)
#endif // UserMessageHandler_h

==> webkitgtk-2.8.2.tar.xz: webkitgtk-2.8.2/Source/WebCore/page/UserMessageHandler.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef UserMessageHandler_h
#define UserMessageHandler_h

#if ENABLE(USER_MESSAGE_HANDLERS)

#include "FrameDestructionObserver.h"
#include "UserMessageHandlerDescriptor.h"
#include <bindings/ScriptValue.h>

namespace WebCore {

class UserMessageHandler : public RefCounted<UserMessageHandler>, public FrameDestructionObserver {
public:
    static Ref<UserMessageHandler> create(Frame& frame, UserMessageHandlerDescriptor& descriptor)
    {
        return adoptRef(*new UserMessageHandler(frame, descriptor));
    }
    virtual ~UserMessageHandler();

    void postMessage(PassRefPtr<SerializedScriptValue>);

    const AtomicString& name();
    DOMWrapperWorld& world();

private:
    UserMessageHandler(Frame&, UserMessageHandlerDescriptor&);
    
    Ref<UserMessageHandlerDescriptor> m_descriptor;
};

} // namespace WebCore

#endif // ENABLE(USER_MESSAGE_HANDLERS)
#endif // UserMessageHandler_h
